@@ -1,14 +1,14 @@
 # License Apache 2.0: (c) 2025 Yoan Sallami (Synalinks Team)
 
-import asyncio
 import copy
 import inspect
 
 from synalinks.src.api_export import synalinks_export
 from synalinks.src.backend.common.json_schema_utils import standardize_schema
 from synalinks.src.backend.common.symbolic_data_model import SymbolicDataModel
-from synalinks.src.utils.naming import auto_name
 from synalinks.src.utils.async_utils import run_maybe_nested
+from synalinks.src.utils.naming import auto_name
+
 
 @synalinks_export("synalinks.JsonDataModel")
 class JsonDataModel:
@@ -397,13 +397,34 @@ class JsonDataModel:
             ops.Suffix(suffix=suffix).call(self),
         )
 
-    def get(self, name, default_value=None):
+    def get(self, key, default=None):
         """Get wrapper to make it easier to access JSON fields.
 
         Args:
-            name (str): The attribute name to access.
+            key (str): The key to access.
+            default (any): The default value if key not found.
         """
-        return copy.deepcopy(self._json.get(name, default_value))
+        return self._json.get(key, default)
+
+    def __getitem__(self, key):
+        """Get item wrapper to make it easier to access JSON fields.
+
+        Args:
+            key (str): The key to access.
+        """
+        return self._json[key]
+
+    def keys(self):
+        """Keys wrapper to make it easier to access JSON fields."""
+        return self._json.keys()
+
+    def values(self):
+        """Values wrapper to make it easier to access JSON fields."""
+        return self._json.values()
+
+    def items(self):
+        """Items wrapper to make it easier to access JSON fields."""
+        return self._json.items()
 
     def update(self, kv_dict):
         """Update wrapper to make it easier to modify JSON fields.
