@@ -3,13 +3,14 @@
 # License Apache 2.0: (c) 2025 Yoan Sallami (Synalinks Team)
 
 import json
+import logging
 import os
+import random
 
-import sentry_sdk
+import numpy as np
 
 from synalinks.src.api_export import synalinks_export
 
-
 # The type of float to use throughout a session.
 _FLOATX = "float32"
 
@@ -25,73 +26,11 @@ _BACKEND = "pydantic"
 # Available backends
 _AVAILABLE_BACKEND = ["pydantic"]
 
-# Enable/Disable telemetry
-_synalinks_telemetry_enabled = True
+# Random seed for reproductability
+_RANDOM_SEED = 123
 
-# Check if sentry have been initialized
-_telemetry_initialized = False
-
-# Attemp to know if the telemetry is enabled from env variables
-if "SYNALINKS_TELEMETRY" in os.environ:
-    try:
-        _synalinks_telemetry_enabled = bool(os.environ.get("SYNALINKS_TELEMETRY"))
-    except Exception:
-        _synalinks_telemetry_enabled = True
-else:
-    _synalinks_telemetry_enabled = True
-
-
-@synalinks_export(
-    [
-        "synalinks.config.is_telemetry_enabled",
-        "synalinks.backend.is_telemetry_enabled",
-    ]
-)
-def is_telemetry_enabled():
-    """Return wether of not the telemetry is enabled
-
-    Returns:
-        (bool): True if the telemetry is enabled False otherwise.
-    """
-    return _synalinks_telemetry_enabled
-
-
-@synalinks_export(
-    [
-        "synalinks.config.disable_telemetry",
-        "synalinks.disable_telemetry",
-    ]
-)
-def disable_telemetry():
-    """Disable the telemetry"""
-    global _synalinks_telemetry_enabled
-    _synalinks_telemetry_enabled = False
-
-
-def maybe_initialize_telemetry():
-    global _telemetry_initialized
-    if not _telemetry_initialized and _synalinks_telemetry_enabled:
-        sentry_sdk.init(
-            dsn="https://b53fc10adc81c3c865734c9b5115082a@o4509456897933312.ingest.de.sentry.io/4509456899637328",  # noqa 501
-            max_breadcrumbs=50,
-            debug=False,
-            # we do NOT collect private/personal information
-            send_default_pii=False,
-            # Set traces_sample_rate to 1.0 to capture 100%
-            # of transactions for tracing.
-            traces_sample_rate=1.0,
-        )
-        _telemetry_initialized = True
-
-
-def capture_exception(error):
-    if _telemetry_initialized:
-        sentry_sdk.capture_exception(error)
-
-
-def capture_message(msg):
-    if _telemetry_initialized:
-        sentry_sdk.capture_message(msg)
+np.random.seed(_RANDOM_SEED)
+random.seed(_RANDOM_SEED)
 
 
 @synalinks_export(["synalinks.config.floatx", "synalinks.backend.floatx"])
@@ -204,6 +143,73 @@ def set_epsilon(value):
     _EPSILON = value
 
 
+@synalinks_export(
+    [
+        "synalinks.config.set_seed",
+        "synalinks.backend.set_seed",
+        "synalinks.set_seed",
+    ]
+)
+def set_seed(value):
+    """Set the value of the random seed for reproductability.
+
+    Args:
+        value (float): The new value of epsilon.
+    """
+    global _RANDOM_SEED
+    _RANDOM_SEED = value
+    np.random.seed(_RANDOM_SEED)
+    random.seed(_RANDOM_SEED)
+
+
+@synalinks_export(
+    [
+        "synalinks.config.get_seed",
+        "synalinks.backend.get_seed",
+        "synalinks.get_seed",
+    ]
+)
+def get_seed():
+    return _RANDOM_SEED
+
+
+@synalinks_export(
+    [
+        "synalinks.config.enable_logging",
+        "synalinks.backend.enable_logging",
+        "synalinks.enable_logging",
+    ]
+)
+def enable_logging(filename=None, debug=False):
+    """
+    Configures and enables logging for the application.
+
+    This function sets up the logging configuration for the application, allowing logs to be output
+    either to a specified file or to the console. The logging level can be set to DEBUG for more
+    verbose logging or INFO for standard logging.
+
+    Args:
+        filename (str): The name of the file where logs should be written. If not provided,
+            logs will be output to the console.
+        debug (bool): If True, sets the logging level to DEBUG. If False, the logging level
+            is set to INFO. Defaults to False.
+
+    The log message format includes the timestamp, log level, and the log message itself.
+    """
+    level = logging.DEBUG if debug else logging.INFO
+    if filename:
+        logging.basicConfig(
+            filename=filename,
+            level=level,
+            format="%(asctime)s - %(levelname)s - %(message)s",
+        )
+    else:
+        logging.basicConfig(
+            level=level,
+            format="%(asctime)s - %(levelname)s - %(message)s",
+        )
+
+
 @synalinks_export(
     [
         "synalinks.config.api_key",
@@ -324,10 +330,13 @@ if os.path.exists(_config_path):
     assert _floatx in {"float16", "float32", "float64"}
     _epsilon = _config.get("epsilon", _EPSILON)
     assert isinstance(_epsilon, float)
+    _seed = _config.get("seed", _RANDOM_SEED)
+    assert isinstance(_seed, int)
 
     set_backend(_backend)
     set_floatx(_floatx)
     set_epsilon(_epsilon)
+    set_seed(_seed)
 
 # Save config file, if possible.
 if not os.path.exists(_synalinks_DIR):
@@ -343,6 +352,7 @@ if not os.path.exists(_config_path):
         "backend": _BACKEND,
         "floatx": _FLOATX,
         "epsilon": _EPSILON,
+        "seed": _RANDOM_SEED,
     }
     try:
         with open(_config_path, "w") as f:
