@@ -1,5 +1,6 @@
 # License Apache 2.0: (c) 2025 Yoan Sallami (Synalinks Team)
 
+import asyncio
 import copy
 import json
 import warnings
@@ -8,10 +9,9 @@ import litellm
 
 from synalinks.src.api_export import synalinks_export
 from synalinks.src.backend import ChatRole
-from synalinks.src.backend.config import capture_exception
-from synalinks.src.backend.config import maybe_initialize_telemetry
 from synalinks.src.saving import serialization_lib
 from synalinks.src.saving.synalinks_saveable import SynalinksSaveable
+from synalinks.src.utils.nlp_utils import shorten_text
 
 
 @synalinks_export(
@@ -112,6 +112,19 @@ class LanguageModel(SynalinksSaveable):
     )
     ```
 
+    **Using Google Gemini models**
+
+    ```python
+    import synalinks
+    import os
+
+    os.environ["GEMINI_API_KEY"] = "your-api-key"
+
+    language_model = synalinks.LanguageModel(
+        model="gemini/gemini-1.5-pro",
+    )
+    ```
+
     To cascade models in case there is anything wrong with
     the model provider (hence making your pipelines more robust).
     Use the `fallback` argument like in this example:
@@ -138,19 +151,21 @@ class LanguageModel(SynalinksSaveable):
     Args:
         model (str): The model to use.
         api_base (str): Optional. The endpoint to use.
-        timeout (int): Optional. The timeout value in seconds (Default to 100).
+        timeout (int): Optional. The timeout value in seconds (Default to 600).
         retry (int): Optional. The number of retry (default to 5).
         fallback (LanguageModel): Optional. The language model to fallback
             if anything is wrong.
+        caching (bool): Optional. Enable caching of LM calls (Default to True).
     """
 
     def __init__(
         self,
         model=None,
         api_base=None,
-        timeout=100,
+        timeout=600,
         retry=5,
         fallback=None,
+        caching=True,
     ):
         if model is None:
             raise ValueError("You need to set the `model` argument for any LanguageModel")
@@ -167,6 +182,7 @@ class LanguageModel(SynalinksSaveable):
             self.api_base = api_base
         self.timeout = timeout
         self.retry = retry
+        self.caching = caching
 
     async def __call__(self, messages, schema=None, streaming=False, **kwargs):
         """
@@ -183,10 +199,10 @@ class LanguageModel(SynalinksSaveable):
         Returns:
             (dict): The generated structured response.
         """
-        maybe_initialize_telemetry()
         formatted_messages = messages.get_json().get("messages", [])
         json_instance = {}
         input_kwargs = copy.deepcopy(kwargs)
+        schema = copy.deepcopy(schema)
         if schema:
             if self.model.startswith("groq"):
                 # Use a tool created on the fly for groq
@@ -243,6 +259,11 @@ class LanguageModel(SynalinksSaveable):
             elif self.model.startswith("openai") or self.model.startswith("azure"):
                 # Use constrained structured output for openai
                 # OpenAI require the field  "additionalProperties"
+                # Also OpenAI disallow the field "description" in $ref
+                if "properties" in schema:
+                    for prop_key, prop_value in schema["properties"].items():
+                        if "$ref" in prop_value and "description" in prop_value:
+                            del prop_value["description"]
                 kwargs.update(
                     {
                         "response_format": {
@@ -255,6 +276,24 @@ class LanguageModel(SynalinksSaveable):
                         }
                     }
                 )
+            elif self.model.startswith("gemini"):
+                kwargs.update(
+                    {
+                        "response_format": {
+                            "type": "json_object",
+                            "json_schema": schema,
+                        }
+                    }
+                )
+            elif self.model.startwith("xai"):
+                kwargs.update(
+                    {
+                        "response_format": {
+                            "type": "json_object",
+                            "json_schema": schema,
+                        }
+                    }
+                )
             else:
                 provider = self.model.split("/")[0]
                 raise ValueError(
@@ -279,7 +318,7 @@ class LanguageModel(SynalinksSaveable):
                     model=self.model,
                     messages=formatted_messages,
                     timeout=self.timeout,
-                    caching=False,
+                    caching=self.caching,
                     **kwargs,
                 )
                 if streaming:
@@ -303,8 +342,12 @@ class LanguageModel(SynalinksSaveable):
                     }
                 return json_instance
             except Exception as e:
-                warnings.warn(f"Error occured while trying to call {self}: " + str(e))
-                capture_exception(e)
+                warnings.warn(
+                    f"Error occured while trying to call {self}: "
+                    + str(e)
+                    + f"\nReceived response={shorten_text(response_str)}"
+                )
+            await asyncio.sleep(1)
         if self.fallback:
             return self.fallback(
                 messages,
@@ -324,6 +367,7 @@ class LanguageModel(SynalinksSaveable):
             "api_base": self.api_base,
             "timeout": self.timeout,
             "retry": self.retry,
+            "caching": self.caching,
         }
         if self.fallback:
             fallback_config = {
