@@ -2,9 +2,9 @@
 # Original authors: François Chollet et al. (Keras Team)
 # License Apache 2.0: (c) 2025 Yoan Sallami (Synalinks Team)
 
-import asyncio
 import collections
 import inspect
+import uuid
 import warnings
 from functools import wraps
 
@@ -13,17 +13,17 @@ from synalinks.src import initializers
 from synalinks.src import tree
 from synalinks.src import utils
 from synalinks.src.api_export import synalinks_export
+from synalinks.src.backend import is_trainable
 from synalinks.src.backend.common import global_state
 from synalinks.src.backend.common.name_scope import current_path
-from synalinks.src.backend.config import capture_exception
-from synalinks.src.backend.config import maybe_initialize_telemetry
+from synalinks.src.hooks.hook_list import HookList
 from synalinks.src.metrics import Metric
 from synalinks.src.ops.operation import Operation
 from synalinks.src.saving.synalinks_saveable import SynalinksSaveable
 from synalinks.src.utils import python_utils
 from synalinks.src.utils import tracking
-from synalinks.src.utils.naming import auto_name
 from synalinks.src.utils.async_utils import run_maybe_nested
+from synalinks.src.utils.naming import auto_name
 
 if backend.backend() == "pydantic":
     from synalinks.src.backend.pydantic.module import PydanticModule as BackendModule
@@ -111,6 +111,7 @@ class Module(BackendModule, Operation, SynalinksSaveable):
         trainable=True,
         name=None,
         description=None,
+        hooks=None,
         **kwargs,
     ):
         BackendModule.__init__(self)
@@ -144,6 +145,10 @@ class Module(BackendModule, Operation, SynalinksSaveable):
         self._build_schemas_dict = None
         # Parent path
         self._parent_path = None
+        self._hooks = HookList(
+            hooks=hooks,
+            module=self,
+        )
         self._initialize_tracker()
 
     @tracking.no_automatic_dependency_tracking
@@ -355,6 +360,7 @@ class Module(BackendModule, Operation, SynalinksSaveable):
         data_model=None,
         trainable=True,
         name=None,
+        description=None,
     ):
         """Add a variable to the module
 
@@ -368,6 +374,9 @@ class Module(BackendModule, Operation, SynalinksSaveable):
                 optimization or whether its updates are managed manually. Defaults
                 to `True`.
             name (string): String name of the variable. Useful for debugging purposes.
+            description (string): String description of the variable. Used by the
+                optimizers to infer the role of the variable. Required if the data
+                model do not have a docstring.
 
         Returns:
             (Variable): The created variable
@@ -375,12 +384,14 @@ class Module(BackendModule, Operation, SynalinksSaveable):
         self._check_super_called()
         if initializer is None:
             initializer = initializers.Empty(data_model=data_model)
+        trainable = trainable and is_trainable(data_model)
         with backend.name_scope(self.name, caller=self):
             variable = backend.Variable(
                 initializer=initializer,
                 data_model=data_model,
                 trainable=trainable,
                 name=name,
+                description=description,
             )
         self._track_variable(variable)
         return variable
@@ -498,8 +509,12 @@ class Module(BackendModule, Operation, SynalinksSaveable):
         )
 
     async def __call__(self, *args, **kwargs):
-        maybe_initialize_telemetry()
-
+        call_id = str(uuid.uuid4())
+        if self._hooks:
+            self._hooks.on_call_begin(
+                call_id=call_id,
+                inputs=args,
+            )
         self._check_super_called()
         self._called = True
 
@@ -515,7 +530,7 @@ class Module(BackendModule, Operation, SynalinksSaveable):
 
         # Used to avoid expensive `tree` operations in the most common case.
         if len(args) == 1 and backend.is_data_model(args[0]):
-            args[0] = args[0].to_json_data_model()
+            args[0] = args[0].to_json_data_model(name=self.name + "_inputs")
         else:
             args = self._maybe_convert_inputs(args)
 
@@ -579,11 +594,20 @@ class Module(BackendModule, Operation, SynalinksSaveable):
             if not self.built:
                 self.built = True
         except Exception as e:
-            capture_exception(e)
+            if self._hooks:
+                self._hooks.on_call_end(
+                    call_id=call_id,
+                    exception=str(e),
+                )
             raise e
         finally:
             # Destroy call context if we created it
             self._maybe_reset_call_context()
+        if self._hooks:
+            self._hooks.on_call_end(
+                call_id=call_id,
+                outputs=outputs,
+            )
         return outputs
 
     async def call(self, *args, **kwargs):
@@ -634,8 +658,22 @@ class Module(BackendModule, Operation, SynalinksSaveable):
         pass
 
     def _maybe_convert_inputs(self, inputs):
+        counter = {"i": 0}
+
+        def convert_fn(x):
+            if backend.is_data_model(x):
+                if counter["i"] > 0:
+                    result = x.to_json_data_model(
+                        name=f"{self.name}_inputs_{counter['i']}"
+                    )
+                else:
+                    result = x.to_json_data_model(name=f"{self.name}_inputs")
+                counter["i"] += 1
+                return result
+            return x
+
         return tree.map_structure(
-            lambda x: x.to_json_data_model() if backend.is_data_model(x) else x,
+            convert_fn,
             inputs,
         )
         return inputs
